@@ -23,11 +23,15 @@ else:
 
 def myPath(path):
     '''Convert any Windows or Linux path to a Linux path. Adds a slash at the end, if missing.'''
-    newPath = re.sub(r'\\', '/', path)
-    newPath = re.sub(r'//', '/', newPath)
-    if not newPath[-1] == '/':
-        newPath += '/'
-    return newPath
+    if path == None:
+        return path
+    try:
+        newPath = re.sub(r'\\', '/', path)
+        if not newPath[-1] == '/':
+            newPath += '/'
+        return newPath
+    except:
+        return path
 
 def offset(ax, x, y):
     return offset_copy(ax.transData, x=x, y=y, units='dots')
@@ -61,7 +65,7 @@ def HREELS_elog_Dictionary(file, path):
 
 class HREELS:
     """This class handles HREELS data and their plotting. """ 
-    path = "\\\\backup-ep3\\BackUp02\\0_experiments\\EELS-PC4\HREELS\\gph_dat\\2019\\"
+    path = "\\\\backup-ep3\\BackUp02\\0_experiments\\EELS-PC4\HREELS\\gph_dat\\"
     # path = "./"
     def __init__(self, _filename, datapath=path):
         global eV2cm
