@@ -16,6 +16,10 @@ import libhreels as hh
 hhPath = hh.__path__[0]
 from libhreels.Auger import Auger
 
+# fix HighRes Displays
+QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
+QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
+
 
 class Auger_Window(QtWidgets.QMainWindow):
     """ fill in some initial data """
@@ -32,7 +36,7 @@ class Auger_Window(QtWidgets.QMainWindow):
         if datapath and os.path.exists(datapath):
             self.datapath = datapath
         else:
-            self.datapath = "\\\\141.48.167.189\\BackUp02\\0_experiments\\EELS-PC4\\AES\\2019"
+            self.datapath = "\\\\141.48.167.189\\BackUp02\\0_experiments\\EELS-PC4\\AES"
         if remoteDir and os.path.exists(remoteDir):
             self.remoteDir = remoteDir
         else:
