@@ -15,10 +15,15 @@ hhPath = os.path.dirname(__file__)
 from libhreels.HREELS import HREELS, myPath
 from datetime import datetime  
 import argparse
+import expLogbook as lgb
+
+# fix HighRes Displays
+QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
+QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
 
 class HREELS_Window(QtWidgets.QMainWindow):
     """ fill in some initial data """
-    def __init__(self,datapath=None, remoteDir=None, startWithFile=None):
+    def __init__(self,datapath=None, remoteDir=None, startWithFile=None, comment=None):
         super(HREELS_Window, self).__init__()
         f = os.path.join(hhPath,"viewhreels.ui")  # path to the package directory. Needed to find graphical user interface files (*.ui)
         self.ui = self.ui = uic.loadUi(f, self)
@@ -27,6 +32,8 @@ class HREELS_Window(QtWidgets.QMainWindow):
         self.offset = 0.1
         self.useOffset = False
         self.normalized = False
+        self.comment = comment
+        self.showComment = lgb.available
         if datapath and os.path.exists(datapath):
             self.datapath = datapath
         else:
@@ -35,7 +42,7 @@ class HREELS_Window(QtWidgets.QMainWindow):
         if remoteDir and os.path.exists(remoteDir):
             self.remoteDir = remoteDir
         else:
-            self.remoteDir = '//141.48.167.189/BackUp02/0_experiments/EELS-PC4/HREELS/gph_dat/2019'
+            self.remoteDir = '//141.48.167.189/BackUp02/0_experiments/EELS-PC4/HREELS/gph_dat/'
         self.wideScan = True
         self.marker = []
         # self.markerSet = False
@@ -48,6 +55,11 @@ class HREELS_Window(QtWidgets.QMainWindow):
         # self.drawing_figure.canvas.mpl_connect('button_press_event', self.onMouse)
         self.drawing_pane.axes = self.drawing_pane.figure.add_subplot(111)
         self.ui.drawWidget.layout().addWidget(self.drawing_pane)
+
+        #Add a cursor:
+        self.cursor = Cursor(self.drawing_pane, self.drawing_pane.axes)
+        # self.cursorId = self.drawing_figure.canvas.mpl_connect('motion_notify_event', self.cursor.mouse_move)
+
         # Add toolbar
         self.xToolbar = NavigationToolbar(self.drawing_pane, self)
         self.ui.drawWidget.layout().addWidget(self.xToolbar)
@@ -58,34 +70,37 @@ class HREELS_Window(QtWidgets.QMainWindow):
         self.ui.lineEdit_factor.setText('%4.1f'%(self.factor))
         self.ui.lineEdit_offset.setText('%4.1f'%(self.offset))
         self.ui.checkBoxWideScans.setChecked(True)
+        self.ui.checkBoxComment.setChecked(lgb.available)
+        # self.ui.listWidget.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
+
 
         # Action on user events
         self.ui.checkBoxWideScans.toggled.connect(self.onWideScans)
         self.ui.checkBoxNormalized.toggled.connect(self.onNormalized)
         self.ui.checkBoxOffset.toggled.connect(self.onUseOffset)
         self.ui.checkBoxMarker.toggled.connect(self.onMarkerSet)
-        self.ui.pushButton_details.pressed.connect(self.onPushButton_details3)
+        self.ui.checkBoxComment.toggled.connect(self.onCommentSet)
+        self.ui.pushButton_details.clicked.connect(self.onPushButton_details)
         self.ui.lineEdit_xmin.editingFinished.connect(self.onXmin)
         self.ui.lineEdit_factor.editingFinished.connect(self.onFactor)
         self.ui.lineEdit_offset.editingFinished.connect(self.onOffset)
         self.ui.lineEdit_directory.editingFinished.connect(self.onNewDirectory)
+        self.ui.listWidget.itemSelectionChanged.connect(self.onFileSelection)
+
+        # Action on user menu events: 
+        self.action_directory.triggered.connect(self.onActionDir)
+        self.action_test.triggered.connect(self.onActionTest)
+        self.action_help.triggered.connect(self.onActionHelp)
+        self.actionFile_info.triggered.connect(self.onPushButton_details)
 
         # Create list of all datafiles in the directory
         self.createFileList()
-        self.ui.listWidget.itemSelectionChanged.connect(self.onFileSelection)
         self.dataDir = QtWidgets.QFileDialog(self)
         if os.name == 'nt':
             self.dataDir.setDirectory("D:\\Data\\Python\\HREELS\\expHREELS\\data")
         else:
             self.dataDir.setDirectory("/mnt/d/Data/Python/HREELS/expHREELS/data")
-        # Action on user menu events: 
-        self.action_directory.triggered.connect(self.onActionDir)
-        self.action_test.triggered.connect(self.onActionTest)
-        self.action_help.triggered.connect(self.onActionHelp)
 
-        #Add a cursor:
-        self.cursor = Cursor(self.drawing_pane, self.drawing_pane.axes)
-        # self.cursorId = self.drawing_figure.canvas.mpl_connect('motion_notify_event', self.cursor.mouse_move)
         if startWithFile:
             self.selectFile(startWithFile)
 
@@ -190,23 +205,7 @@ class HREELS_Window(QtWidgets.QMainWindow):
         msg.buttonClicked.connect(self.onOK)            
         msg.exec_()
 
-    # def onPushButton_details(self):
-    #     try:
-    #         details = self.d.infoText()
-    #     except:
-    #         return
-    #     msg = QtWidgets.QMessageBox()
-    #     msg.setText(details)
-    #     msg.setWindowTitle("Dataset details")
-    #     msg.setStandardButtons(QtWidgets.QMessageBox.Ok)
-    #     layout = msg.layout()
-    #     widget = QtWidgets.QWidget()
-    #     widget.setFixedSize(650, 1)
-    #     layout.addWidget(widget, 3, 0, 1, 3)
-    #     msg.buttonClicked.connect(self.onOK)            
-    #     msg.exec_()
-
-    def onPushButton_details3(self):
+    def onPushButton_details(self):
         """Routine for showing a dialog window containing HREELS data details"""
         try:
             self.d.infoText()
@@ -234,6 +233,27 @@ class HREELS_Window(QtWidgets.QMainWindow):
             self.canvasId = self.drawing_figure.canvas.mpl_connect('button_press_event', self.onMouse)
             print('mouse enabled')
 
+    def onCommentSet(self):
+        '''Routine called if selection "Show Comment" is toggled. It allows to draw dashed vertical lines
+        with the energy loss values. The value 'self.markerSet' is used to decide later if lines have to be drawn.'''
+        self.showComment =  self.ui.checkBoxComment.isChecked()
+        # print('onCommentSet:', lgb.available, self.showComment, self.ui.listWidget.selectedItems()[0].text())
+        if self.showComment:
+            if lgb.available:
+                text = lgb.logbook.getShortMessage4File(self.d.fname)
+                ids = lgb.logbook.search({'file':self.d.fname})
+                _, attributes, _ = lgb.logbook.read(ids[0])
+                print(self.d.fname, ids[0],':\t\t', attributes['Date'],'\t',text)
+            else:
+                text = self.comment if self.comment else ''
+                self.comment = None
+            self.pCom = self.drawing_pane.axes.text(0.12, 0.98,text, ha='left', va='top', transform=self.drawing_pane.axes.transAxes)
+        else:
+            try:
+                self.pCom.remove()
+            except:
+                pass
+
     def onOK(self, button):
         print("Button pressed is:",button.text())
 
@@ -249,18 +269,22 @@ class HREELS_Window(QtWidgets.QMainWindow):
     def selectFile(self, file):
         '''Select the file within the QListWidget by the program, e.g. as start parameter. 
         Make sure before that it exists. The file extension is dropped by re.split. '''
-        itm = self.ui.listWidget.findItems(re.split('\.',file)[0], QtCore.Qt.MatchExactly)
-        self.ui.listWidget.setCurrentItem(itm[0])
+        matchingItems = self.ui.listWidget.findItems(re.split('\.',file)[0], QtCore.Qt.MatchExactly)
+        self.ui.listWidget.setCurrentItem(matchingItems[0])
+        for it in matchingItems:
+            it.setSelected(True)
+        self.ui.listWidget.setFocus()
         return
 
     def onFileSelection(self):
         '''Routine called if user makes a file selection or changes the file selection within the left list.
-        The selected spectra are plotted according to the givcen flags (Xmin, Factor, Normalized, Offset). '''
+        The selected spectra are plotted according to the given flags (Xmin, Factor, Normalized, Offset). '''
         iMax = len(self.ui.listWidget.selectedItems())
         if iMax == 0:
             return
+        # print([it.text() for it in self.ui.listWidget.selectedItems()])
         firstItem = self.ui.listWidget.selectedItems()[0]
-        # self.d = HREELS(firstItem.text(),self.datapath)
+
         self.d = HREELS(firstItem.text(),self.datapath)
         if self.d.valid:
             plotColor = plt.cm.gnuplot(0)     # Define the color map (coolwarm; plasma; inferno; gnuplot)         
@@ -275,11 +299,12 @@ class HREELS_Window(QtWidgets.QMainWindow):
             return
         if iMax > 1:
             i = 1.
-            for item in self.ui.listWidget.selectedItems()[1:]:
+            myList = self.ui.listWidget.selectedItems()[1:]
+            for item in myList:     # Add here sorting according to ...
                 plotColor = plt.cm.gnuplot(i/iMax)     # Define the color map (coolwarm; plasma; inferno; gnuplot)
                 self.d = HREELS(item.text(),self.datapath)
                 self.secondPlot(xmin=self.xmin, factor=self.factor, normalized=self.normalized, offset=i*self.offset*self.useOffset, color=plotColor)
-                print(i, item.text())
+                # print(i, item.text())
                 i += 1
         # Reversing the sequence of labels in the legend:
         handles, labels = self.drawing_pane.axes.get_legend_handles_labels()
@@ -317,14 +342,15 @@ class HREELS_Window(QtWidgets.QMainWindow):
     def updatePlot(self,xmin=70, factor=10, normalized=False, color="red"):
         '''Plotting the first of the selected spectra. '''
         self.drawing_pane.axes.cla()
-        self.plotWidget(normalized=normalized)
-        self.plotWidget(xmin=xmin, factor=factor, color=color, label='x %3i'%factor, normalized=normalized)
+        self.plotWidget(normalized=normalized,showComment=False)
+        self.plotWidget(xmin=xmin, factor=factor, color=color, label='x %3i'%factor, normalized=normalized, showComment=self.showComment)
 
     def secondPlot(self,xmin=70, factor=10, normalized=False, offset = 0., color="b-"):
         '''Plotting the second and all further selected spectra. '''
         self.plotWidget(xmin=xmin, factor=factor, color=color, label=self.d.fname, normalized=normalized, offset = offset)
 
-    def plotWidget(self, xmin=None, xmax=None, factor=1, label='x', normalized=False, color="black",marker=True, offset = 0.):
+    def plotWidget(self, xmin=None, xmax=None, factor=1, label='x', normalized=False, color="black",
+                        marker=True, offset = 0., showComment=False):
         ''' plot(self, xmin=None, xmax=None, factor=1, label='x', normalized=False, color="b-",marker=True)'''
         self.d.pFactor = factor
         if xmin:
@@ -341,6 +367,7 @@ class HREELS_Window(QtWidgets.QMainWindow):
             label = self.d.fname        
         self.drawing_pane.axes.plot(self.d.xdata[nstart:nend], factor*self.d.ydata[nstart:nend] + offset, color=color, label=label)
         self.d.factor = factor
+        if showComment: self.onCommentSet()
         self.drawing_pane.axes.set_xlabel('Energy Loss (cm$^{-1}$)')
         if normalized:
             self.drawing_pane.axes.set_ylabel('Normalized Intensity')
@@ -363,7 +390,8 @@ class HREELS_Window(QtWidgets.QMainWindow):
             time = os.path.getmtime(location)
             if size>sizeMin:
                 files.append((file, time, size))
-        files.sort(key=lambda s: -s[1])  # sort by time
+        # files.sort(key=lambda s: -s[1])  # sort by time
+        files.sort(key=lambda s: s[1])  # sort by reversed time
         fileNames = [item[0] for item in files]
         data_ext = ['gph', 'GPH']
         gphFiles = [fn for fn in fileNames
@@ -400,31 +428,32 @@ class Cursor(object):
         self.ly.set_data([event.xdata, event.xdata], [0, 1])
         self.figure.draw()
 
-def runViewer(datapath= None, remoteDir=None, startWithFile=None):
+def runViewer(datapath= None, remoteDir=None, startWithFile=None, comment=None):
     """ Main function for graphical application start """
     app = QtWidgets.QApplication(sys.argv)
-    form = HREELS_Window(datapath=datapath, remoteDir=remoteDir, startWithFile=startWithFile)
+    form = HREELS_Window(datapath=datapath, remoteDir=remoteDir, startWithFile=startWithFile, comment=comment)
     form.show()
     sys.exit(app.exec_())
 
-#################  Command line handling  ######################
-def validDate(string):
-    date = datetime.strptime(string, "%Y-%m-%d")
-    return date
-def is_valid_file(string):
-    if not os.path.exists(string):
-        parser.error("The file %s does not exist!" % string)
-        return False
-    else:
-        return string
 
 def myMain():
     parser = argparse.ArgumentParser()
-    # parser.add_argument("-v", "--verbosity", type=int, choices=[0, 1, 2],help="increase output verbosity")
-    parser.add_argument("-s", "--start", help="Start date (2018-01-01)", default='2019-01-01', type=validDate)
-    #parser.add_argument("-e", "--end", help="End date and time (2018-01-01_08:00)", type=validDate, required=True)
+    #################  Command line handling  ######################
+    def validDate(string):
+        date = datetime.strptime(string, "%Y-%m-%d")
+        return date
+    def is_valid_file(string):
+        if not os.path.exists(string):
+            parser.error("The file %s does not exist!" % string)
+            return False
+        else:
+            return string
+    # parser.add_argument("-s", "--start", help="Start date (2018-01-01)", default='2019-01-01', type=validDate)
     parser.add_argument("-f", "--file", help="Start viewer with this datafile", type=is_valid_file)
+    # parser.add_argument("-f", "--file", help="Start viewer with this datafile")
+    parser.add_argument("-c", "--comment", default=None, help="Text comment")
     args = parser.parse_args()
+
     if args.file:
         fPath,fName = os.path.split(args.file)
         # print(">>> ", fPath, " <<< ", fName)
@@ -435,7 +464,10 @@ def myMain():
             fPath = "/mnt/d/Data/Python/HREELS/expHREELS/data"
         fName = None
 
-    runViewer(datapath=fPath, startWithFile=fName)
+    runViewer(datapath=fPath, startWithFile=fName, comment=args.comment)
+
+
+
 
 if __name__ == '__main__':
 	myMain()
\ No newline at end of file
